package com.xhpc.charging.station.mapper;

import com.xhpc.common.domain.TimingTerminalDeactivate;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * @author yuyang
 * @Date 2026-05-08 13:43
 */
public interface TimingTerminalDeactivateMapper {
    /**
     * 查询桩停用调整列表（带关联查询）
     */
    public List<TimingTerminalDeactivate> selectDeactivateList(TimingTerminalDeactivate deactivate);

    /**
     * 批量更新执行状态
     */
    public int batchUpdateType(@Param("list") List<Long> ids, @Param("type") Integer type, @Param("errorReason") String errorReason);

    TimingTerminalDeactivate getTimingTerminalDeactivateById( @Param("id")Long id);

    int addTimingTerminalDeactivate(TimingTerminalDeactivate deactivate);

    int updateTimingTerminalDeactivate(TimingTerminalDeactivate deactivate);

    int deleteTimingTerminalDeactivate(@Param("ids")Long ids);

    List<TimingTerminalDeactivate> getTimingTerminalDeactivateTime(@Param("status")Integer status);

    List<Map<String, Object>> getSerialNumberList(@Param("ids")List<String> ids);

    int updateXhpcTerminalAll(@Param("status")Integer status,@Param("prompt")String prompt,@Param("ids")List<String> ids);
}
